==> org.apache.sling.fsresource-2.1.14-source-release.zip: org.apache.sling.fsresource-2.1.14/src/test/java/org/apache/sling/fsprovider/internal/InitialContentImportOptionsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.fsprovider.internal;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

import com.google.common.collect.ImmutableSet;

public class InitialContentImportOptionsTest {

    @Test
    public void testNull() {
        InitialContentImportOptions underTest = new InitialContentImportOptions(null);
        assertFalse(underTest.isOverwrite());
        assertTrue(underTest.getIgnoreImportProviders().isEmpty());
    }

    @Test
    public void testBlank() {
        InitialContentImportOptions underTest = new InitialContentImportOptions(" ");
        assertFalse(underTest.isOverwrite());
        assertTrue(underTest.getIgnoreImportProviders().isEmpty());
    }

    @Test
    public void testOptions1() {
        InitialContentImportOptions underTest = new InitialContentImportOptions("overwrite:=true;ignoreImportProviders:=\"xml,json\"");
        assertTrue(underTest.isOverwrite());
        assertEquals(ImmutableSet.of("xml","json"), underTest.getIgnoreImportProviders());
    }

    @Test
    public void testOptions2() {
        InitialContentImportOptions underTest = new InitialContentImportOptions(" overwrite := false ; ignoreImportProviders := xml ");
        assertFalse(underTest.isOverwrite());
        assertEquals(ImmutableSet.of("xml"), underTest.getIgnoreImportProviders());
    }

}

==> org.apache.sling.fsresource-2.3.0-source-release.zip: org.apache.sling.fsresource-2.3.0/src/test/java/org/apache/sling/fsprovider/internal/InitialContentImportOptionsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.fsprovider.internal;

import com.google.common.collect.ImmutableSet;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class InitialContentImportOptionsTest {

    @Test
    public void testNull() {
        InitialContentImportOptions underTest = new InitialContentImportOptions(null);
        assertFalse(underTest.isOverwrite());
        assertTrue(underTest.getIgnoreImportProviders().isEmpty());
    }

    @Test
    public void testBlank() {
        InitialContentImportOptions underTest = new InitialContentImportOptions(" ");
        assertFalse(underTest.isOverwrite());
        assertTrue(underTest.getIgnoreImportProviders().isEmpty());
    }

    @Test
    public void testOptions1() {
        InitialContentImportOptions underTest =
                new InitialContentImportOptions("overwrite:=true;ignoreImportProviders:=\"xml,json\"");
        assertTrue(underTest.isOverwrite());
        assertEquals(ImmutableSet.of("xml", "json"), underTest.getIgnoreImportProviders());
    }

    @Test
    public void testOptions2() {
        InitialContentImportOptions underTest =
                new InitialContentImportOptions(" overwrite := false ; ignoreImportProviders := xml ");
        assertFalse(underTest.isOverwrite());
        assertEquals(ImmutableSet.of("xml"), underTest.getIgnoreImportProviders());
    }
}
